IntervalMaxEnd

Struct IntervalMaxEnd 

pub struct IntervalMaxEnd;
Augmentation for interval trees: tracks the maximum interval endpoint in each subtree.

When keys are interval start points and values are interval end points, this augmentation allows efficient overlap queries: if root_stats() < query_start, no interval overlaps.

Examples

use augmented_rbtree::{AugmentedRBTree, augmentations::IntervalMaxEnd};

// Key = interval start, Value = interval end
let mut tree = AugmentedRBTree::<i32, i32, IntervalMaxEnd>::new();
tree.insert(1, 5);   // interval [1, 5]
tree.insert(3, 10);  // interval [3, 10]
tree.insert(8, 12);  // interval [8, 12]

// Max endpoint in the whole tree
assert_eq!(tree.root_stats(), Some(&Some(12)));