pub enum TreeLocation<Q> {
Root,
At(Q),
Leftmost,
Rightmost,
LowerBound(Bound<Q>),
UpperBound(Bound<Q>),
}Expand description
It is used to specify the location of the node in the tree where the cursor should be initially positioned.
Variants
Root
Root of the tree
At(Q)
Position at a specific key
Leftmost
The cursor will be positioned at the leftmost (minimum) node in the tree.
Rightmost
Rightmost (maximum) node in the tree.
LowerBound(Bound<Q>)
The cursor will be positioned at the first node whose key is greater than (or equal) to the given key depending on the bound type.
UpperBound(Bound<Q>)
The cursor will be positioned at the first node whose key is less than (or equal) to the given key depending on the bound type.