pub struct Interval<T> {
pub lo: T,
pub hi: T,
}Available on crate feature
interval-tree only.Expand description
A closed interval [lo, hi] used as a key in IntervalTree.
Intervals are ordered by their lower endpoint (lo). Two intervals with the
same lo are further ordered by their upper endpoint (hi).
Fields
lo: TInclusive lower bound.
hi: TInclusive upper bound.
Implementations
Sourceimpl<T: Ord> Interval<T>
impl<T: Ord> Interval<T>
Sourcepub fn overlaps(&self, other: &Self) -> bool
pub fn overlaps(&self, other: &Self) -> bool
Returns true if this interval overlaps with other.
Two intervals overlap if they share at least one point:
[a, b] overlaps [c, d] iff a <= d && c <= b.
Sourcepub fn contains_point(&self, point: &T) -> bool
pub fn contains_point(&self, point: &T) -> bool
Returns true if this interval contains point.