constant_augment

Macro constant_augment 

macro_rules! constant_augment {
    ($name:ident, $type:ty, $val:expr) => { ... };
}
Dynamically generates a custom constant Augment type.

This eliminates the need to manage external traits or deal with const-generic limitations when configuring a tree with a fixed baseline value.

Examples

constant_augment!(MyConstantAugment, i32, 42);