NodeGuard

Struct NodeGuard 

pub struct NodeGuard<'a, K, V, S, P>
where P: TreePolicy<K = K, V = V, S = S>,
{ /* private fields */ }
A guarded mutable reference to an augmented tree node.

Modifying the underlying value via this guard automatically propagates augmentation updates up the tree when it goes out of scope.

Implementations

Source

impl<K, V, S, P> NodeGuard<'_, K, V, S, P>
where P: TreePolicy<K = K, V = V, S = S>,

pub fn key(&self) -> &K

Returns a reference to the key of the guarded node.

pub fn stats(&self) -> &S

Returns a reference to the statistics of the guarded node.

pub fn value_mut(&mut self) -> &mut V

Returns a mutable reference to the value of the guarded node.

pub fn value(&self) -> &V

Returns a reference to the value of the guarded node.