VacantEntry

Struct VacantEntry 

pub struct VacantEntry<'a, K, V, S, A, P>
where P: TreePolicy<K = K, V = V, S = S>, K: Ord, A: Allocator,
{ /* private fields */ }
A view into a vacant entry in an AugmentedRBTree.

Implementations

Source

impl<'a, K, V, S, A, P> VacantEntry<'a, K, V, S, A, P>
where K: Ord, P: TreePolicy<K = K, V = V, S = S>, A: Allocator,

pub fn key(&self) -> &K

Gets a reference to the key that would be used when inserting a value through the VacantEntry.

pub fn into_key(self) -> K

Take ownership of the key.

pub fn try_insert(self, value: V) -> Result<&'a mut V, OutOfMemoryError>
where P: TreePolicy<K = K, V = V, S = S>,

Try to insert a value with the VacantEntry’s key, and returns a mutable reference to it.

Errors

Returns an OutOfMemoryError if the allocation fails.

pub fn insert(self, value: V) -> &'a mut V

Set the value of the entry with the VacantEntry’s key, and returns a mutable reference to it.