ValueGuard

Struct ValueGuard 

pub struct ValueGuard<'a, K, V, S, P>
where P: TreePolicy<K = K, V = V, S = S>,
{ /* private fields */ }
A guarded mutable reference to an augmented tree node value.

Modifying the underlying value via this guard automatically propagates augmentation updates up the tree when it goes out of scope.